<?php
namespace yrm;
use \ReadMoreAdminHelper;

if (!class_exists('yrm\EDD_SL_Plugin_Updater')) {
	// load our custom updater if it doesn't already exist
	require_once(YRM_LIB_FILES .'EDD_SL_Plugin_Updater.php');
}
define('YRM_LICENCE_REDIRECT', admin_url()."admin.php?page=rmmore-license");

class Updates {
	private $licenses = array();
	
	public function setLicenses($licenses) {
		$this->licenses = $licenses;
	}
	
	public function getLicenses() {
		return $this->licenses;
	}
	
	public function __construct() {
		$this->init();
	}
	
	public function setExtensionsLicenses() {
		$registered = ReadMoreAdminHelper::getOption('YRM_REGISTERED_PLUGINS');
		$registered = json_decode($registered, true);
		
		if (empty($registered)) {
			return false;
		}
		$licenses = array();
		foreach ($registered as $register) {
			
			if (empty($register['licence'])) {
				continue;
			}
			
			$licenses[] = $register['licence'];
		}
		
		$this->setLicenses($licenses);
		
		return true;
	}
	
	private function init() {
		$this->setExtensionsLicenses();
		
		add_action('admin_menu', array($this, 'menu'), 22);
		add_action('admin_init', array($this, 'yrmActivateLicense'));
		add_action('admin_notices', array($this, 'adminNotices'));
		
		$this->updates();
		
		return true;
	}
	
	private function updates() {
		$licenses = $this->getLicenses();
		foreach ($licenses as $license) {
			$key = $license['key'];
			$storeURL = $license['storeURL'];
			$pluginMainFilePath = $license['file'];
			
			$pluginMainFilePath = WP_PLUGIN_DIR.'/'.$pluginMainFilePath;
			
			$licenseKey = trim(get_option('yrm-license-key-'.$key));
			$status = get_option('yrm-license-status-'.$key);
			
			if ($status == false || $status != 'valid') {
				continue;
			}
			
			$version = @constant('YRM_VERSION_'.$key);
			// If the version of the extension is not found, update will not possibly be shown
			if(empty($version)) {
				continue;
			}
			new EDD_SL_Plugin_Updater($storeURL, $pluginMainFilePath, array(
				'version' 	=> $version,		// current version number
				'license' 	=> $licenseKey,	// license key (used get_option above to retrieve from DB)
				'item_id'   => $license['itemId'],	// id of this plugin
				'item_name' => $license['itemName'], // name of this plugin
				'author' 	=> $license['author'],	// author of this plugin
				'url'       => home_url(),
				'beta'      => false // set to true if you wish customers to receive update notifications of beta releases
			));
		}
	}
	
	public function menu()
	{
		add_submenu_page('readMore', __('License', YRM_LANG), __('License', YRM_LANG), 'read','rmmore-license', array($this, 'pluginLicense'));
	}
	
	public function sanitizeLicense($new)
	{
		$old = get_option('yrm-license-key-'.$this->licenseKey);
		
		if ($old && $old != $new) {
			delete_option('yrm-license-status-'.$this->licenseKey); // new license has been entered, so must reactivate
		}
		update_option('yrm-license-key-'.$this->licenseKey, $new);
		
		return $new;
	}
	
	public function pluginLicense() {
		require_once YRM_VIEWS.'license.php';
	}
	
	public function yrmActivateLicense() {
		
		$licenses = $this->getLicenses();
		
		foreach ($licenses as $license) {
			$key = $license['key'];
			$itemId = $license['itemId'];
			$itemName = $license['itemName'];
			$storeURL = $license['storeURL'];
			$this->licenseKey = $key;
			
			if (isset($_POST['yrm-license-key-'.$key])) {
				$this->sanitizeLicense($_POST['yrm-license-key-'.$key]);
			}
			
			// listen for our activate button to be clicked
			if (isset($_POST['yrm-license-activate-'.$key])) {
				// run a quick security check
				if (!check_admin_referer('yrm_nonce', 'yrm_nonce')) {
					return; // get out if we didn't click the Activate button
				}
				// retrieve the license from the database
				$license = trim(get_option('yrm-license-key-'.$key));
				
				// data to send in our API request
				$apiParams = array(
					'edd_action' => 'activate_license',
					'license'    => $license,
					'item_id'    => $itemId, // The ID of the item in EDD
					'item_name'  => $itemName, // The Name of the item in EDD
					'url'        => home_url()
				);
				// Call the custom API.
				$response = wp_remote_post($storeURL, array('timeout' => 15, 'sslverify' => false, 'body' => $apiParams));
			
				// make sure the response came back okay
				if (is_wp_error($response) || 200 !== wp_remote_retrieve_response_code($response)) {
					$errorMessage = $response->get_error_message();
					$message = (is_wp_error($response) && ! empty($errorMessage)) ? $errorMessage : __('An error occurred, please try again.', YRM_LANG);
				}
				else {
					$licenseData = json_decode(wp_remote_retrieve_body($response));
					if (false === $licenseData->success) {
						switch ($licenseData->error) {
							case 'expired' :
								$message = sprintf(
									__('Your license key expired on %s.', YRM_LANG),
									date_i18n(get_option('date_format'), strtotime($licenseData->expires, current_time('timestamp')))
								);
								break;
							case 'revoked' :
								$message = __('Your license key has been disabled.', YRM_LANG);
								break;
							case 'missing' :
								$message = __('Invalid license.', YRM_LANG);
								break;
							case 'invalid' :
							case 'site_inactive' :
								$message = __('Your license is not active for this URL.',YRM_LANG);
								break;
							case 'item_name_mismatch' :
								$message = sprintf(__('This appears to be an invalid license key for %s.', YRM_LANG), $itemName);
								break;
							case 'no_activations_left' :
								$message = __('You\'ve already used the permitted number of this license key!', YRM_LANG);
								break;
							default :
								$message = __('An error occurred, please try again.', YRM_LANG);
								break;
						}
					}
				}
				// Check if anything passed on a message constituting a failure
				$baseUrl = YRM_LICENCE_REDIRECT;
				if (!empty($message)) {
					$redirect = add_query_arg(array('sl_activation' => 'false', 'message' => urlencode($message)), $baseUrl);
					wp_redirect($redirect);
					exit();
				}
				// $licenseData->license will be either "valid" or "invalid"
				update_option('yrm-license-status-'.$key, $licenseData->license);
				$hasInactiveExtensions = ExtensionRegister::hasInactiveExtensions();
				// all available extensions have active license status
				if (empty($hasInactiveExtensions)) {
					// and if we don't have inactive extensions, remove option, until new one activation
					delete_option('YRM_INACTIVE_EXTENSIONS', 'inactive');
				}
				wp_redirect(YRM_LICENCE_REDIRECT);
				exit();
			}
			
			if (isset($_POST['yrm-license-deactivate'.$key])) {
				$license = trim(get_option('yrm-license-key-'.$key));
				// data to send in our API request
				$apiParams = array(
					'edd_action' => 'deactivate_license',
					'license'    => $license,
					'item_id'    => $itemId, // The ID of the item in EDD
					'item_name'  => $itemName, // The Name of the item in EDD
					'url'        => home_url()
				);
				
				// Send the remote request
				$response = wp_remote_post($storeURL, array('body' => $apiParams, 'timeout' => 15, 'sslverify' => false));
				if (is_wp_error($response) || 200 !== wp_remote_retrieve_response_code($response)) {
					$errorMessage = $response->get_error_message();
					$message = (is_wp_error($response) && ! empty($errorMessage)) ? $errorMessage : __('An error occurred, please try again.', YRM_LANG);
					$baseUrl = YRM_LICENCE_REDIRECT;
					$redirect = add_query_arg(array('message' => urlencode($message)), $baseUrl);
					wp_redirect($redirect);
					exit();
				}
				else {
					$status = false;
					$licenseData = json_decode(wp_remote_retrieve_body($response));
					if (isset($licenseData->success)) {
						$status = $licenseData->success;
					}
					update_option('yrm-license-status-'.$key, $status);
					update_option('YRM_INACTIVE_EXTENSIONS', 'inactive');
					wp_redirect(YRM_LICENCE_REDIRECT);
					exit();
				}
			}
		}
	}
	
	public function adminNotices()
	{
		if (isset($_GET['sl_activation']) && !empty($_GET['message'])) {
			switch ($_GET['sl_activation']) {
				case 'false':
					$message = urldecode($_GET['message']);
					?>
					<div class="error">
						<p><?php echo $message; ?></p>
					</div>
					<?php
					break;
				case 'true':
					break;
			}
		}
	}
}
